@@ -1,7 +1,7 @@
-local S = homedecor_i18n.gettext
+local S = homedecor.gettext
 local modpath = minetest.get_modpath("building_blocks")
 
 dofile(modpath.."/alias.lua")
 dofile(modpath.."/node_stairs.lua")
 dofile(modpath.."/others.lua")
-dofile(modpath.."/recipes.lua")
\ No newline at end of file
+dofile(modpath.."/recipes.lua")
